import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:intl/intl.dart' as intl;

import 'translations_bn.dart';
import 'translations_en.dart';
import 'translations_gu.dart';
import 'translations_hi.dart';
import 'translations_kn.dart';
import 'translations_ml.dart';
import 'translations_mr.dart';
import 'translations_or.dart';
import 'translations_pa.dart';
import 'translations_ta.dart';
import 'translations_te.dart';
import 'translations_ur.dart';

/// Callers can lookup localized strings with an instance of Translations returned
/// by `Translations.of(context)`.
///
/// Applications need to include `Translations.delegate()` in their app's
/// localizationDelegates list, and the locales they support in the app's
/// supportedLocales list. For example:
///
/// ```
/// import 'l10n/translations.dart';
///
/// return MaterialApp(
///   localizationsDelegates: Translations.localizationsDelegates,
///   supportedLocales: Translations.supportedLocales,
///   home: MyApplicationHome(),
/// );
/// ```
///
/// ## Update pubspec.yaml
///
/// Please make sure to update your pubspec.yaml to include the following
/// packages:
///
/// ```
/// dependencies:
///   # Internationalization support.
///   flutter_localizations:
///     sdk: flutter
///   intl: any # Use the pinned version from flutter_localizations
///
///   # rest of dependencies
/// ```
///
/// ## iOS Applications
///
/// iOS applications define key application metadata, including supported
/// locales, in an Info.plist file that is built into the application bundle.
/// To configure the locales supported by your app, you’ll need to edit this
/// file.
///
/// First, open your project’s ios/Runner.xcworkspace Xcode workspace file.
/// Then, in the Project Navigator, open the Info.plist file under the Runner
/// project’s Runner folder.
///
/// Next, select the Information Property List item, select Add Item from the
/// Editor menu, then select Localizations from the pop-up menu.
///
/// Select and expand the newly-created Localizations item then, for each
/// locale your application supports, add a new item and select the locale
/// you wish to add from the pop-up menu in the Value field. This list should
/// be consistent with the languages listed in the Translations.supportedLocales
/// property.
abstract class Translations {
  Translations(String locale)
      : localeName = intl.Intl.canonicalizedLocale(locale.toString());

  final String localeName;

  static Translations of(BuildContext context) {
    return Localizations.of<Translations>(context, Translations)!;
  }

  static const LocalizationsDelegate<Translations> delegate =
      _TranslationsDelegate();

  /// A list of this localizations delegate along with the default localizations
  /// delegates.
  ///
  /// Returns a list of localizations delegates containing this delegate along with
  /// GlobalMaterialLocalizations.delegate, GlobalCupertinoLocalizations.delegate,
  /// and GlobalWidgetsLocalizations.delegate.
  ///
  /// Additional delegates can be added by appending to this list in
  /// MaterialApp. This list does not have to be used at all if a custom list
  /// of delegates is preferred or required.
  static const List<LocalizationsDelegate<dynamic>> localizationsDelegates =
      <LocalizationsDelegate<dynamic>>[
    delegate,
    GlobalMaterialLocalizations.delegate,
    GlobalCupertinoLocalizations.delegate,
    GlobalWidgetsLocalizations.delegate,
  ];

  /// A list of this localizations delegate's supported locales.
  static const List<Locale> supportedLocales = <Locale>[
    Locale('bn'),
    Locale('en'),
    Locale('gu'),
    Locale('hi'),
    Locale('kn'),
    Locale('ml'),
    Locale('mr'),
    Locale('or'),
    Locale('pa'),
    Locale('ta'),
    Locale('te'),
    Locale('ur')
  ];

  /// No description provided for @portFolio.
  ///
  /// In en, this message translates to:
  /// **'Portfolio'**
  String get portFolio;

  /// No description provided for @portfolioDesc.
  ///
  /// In en, this message translates to:
  /// **'Discover, Investments and more'**
  String get portfolioDesc;

  /// No description provided for @discover.
  ///
  /// In en, this message translates to:
  /// **'Discover'**
  String get discover;

  /// No description provided for @investment.
  ///
  /// In en, this message translates to:
  /// **'Investments'**
  String get investment;

  /// No description provided for @homeCardDec2.
  ///
  /// In en, this message translates to:
  /// **'Fractional shares of Top 25 Stocks through ETFs starting as low as ₹100'**
  String get homeCardDec2;

  /// No description provided for @homeCardDec1.
  ///
  /// In en, this message translates to:
  /// **'Select the best Chhotastock suited for your needs'**
  String get homeCardDec1;

  /// No description provided for @funds.
  ///
  /// In en, this message translates to:
  /// **'Funds'**
  String get funds;

  /// No description provided for @noBrokerConnected.
  ///
  /// In en, this message translates to:
  /// **'No broker connected'**
  String get noBrokerConnected;

  /// No description provided for @account.
  ///
  /// In en, this message translates to:
  /// **'Account'**
  String get account;

  /// No description provided for @orders.
  ///
  /// In en, this message translates to:
  /// **'Orders'**
  String get orders;

  /// No description provided for @ordersHistory.
  ///
  /// In en, this message translates to:
  /// **'Order history, status and more'**
  String get ordersHistory;

  /// No description provided for @logoutBroker.
  ///
  /// In en, this message translates to:
  /// **'Logout From Broker'**
  String get logoutBroker;

  /// No description provided for @disconnectYourAccount.
  ///
  /// In en, this message translates to:
  /// **'Disconnect your trading account'**
  String get disconnectYourAccount;

  /// No description provided for @poweredBy.
  ///
  /// In en, this message translates to:
  /// **'Powered by'**
  String get poweredBy;

  /// No description provided for @version.
  ///
  /// In en, this message translates to:
  /// **'Version 1.0'**
  String get version;

  /// No description provided for @pastPerformanceTxt.
  ///
  /// In en, this message translates to:
  /// **'Past performance includes all rebalances & does not include cost or guarantee future returns.'**
  String get pastPerformanceTxt;

  /// No description provided for @loading.
  ///
  /// In en, this message translates to:
  /// **'Loading....'**
  String get loading;

  /// No description provided for @somethingWentWrong.
  ///
  /// In en, this message translates to:
  /// **'Something went wrong.'**
  String get somethingWentWrong;

  /// No description provided for @retry.
  ///
  /// In en, this message translates to:
  /// **'Retry'**
  String get retry;

  /// No description provided for @exitStock.
  ///
  /// In en, this message translates to:
  /// **'Exit from Chhota Stocks'**
  String get exitStock;

  /// No description provided for @exitStock.
  ///
  /// In en, this message translates to:
  /// **'Exit from Chhota Stocks'**
  String get exitStockLabel;

  /// No description provided for @investCTA.
  ///
  /// In en, this message translates to:
  /// **'Invest Now'**
  String get investCTA;

  /// No description provided for @orderSubmitted.
  ///
  /// In en, this message translates to:
  /// **'Order Submitted!'**
  String get orderSubmitted;

  /// No description provided for @viewOrder.
  ///
  /// In en, this message translates to:
  /// **'View Orders'**
  String get viewOrder;

  /// No description provided for @emptyBasket.
  ///
  /// In en, this message translates to:
  /// **'No Chhota Stocks available!'**
  String get emptyBasket;

  /// No description provided for @stocksAndWeight.
  ///
  /// In en, this message translates to:
  /// **'Stocks & Weights'**
  String get stocksAndWeight;

  /// No description provided for @overview.
  ///
  /// In en, this message translates to:
  /// **'Overview'**
  String get overview;

  /// No description provided for @chhotaStocksInfo1.
  ///
  /// In en, this message translates to:
  /// **'Constituents of this Chhotastock were last reviewed on Dec 15 2021, and will be next reviewed on the Jan 15 2022'**
  String get chhotaStocksInfo1;

  /// No description provided for @chhotaStocksInfo2.
  ///
  /// In en, this message translates to:
  /// **'Where is it invested?'**
  String get chhotaStocksInfo2;

  /// No description provided for @chhotaStocksInfo3.
  ///
  /// In en, this message translates to:
  /// **'Every unit purchased in this chhotastock is invested in multiple stocks & segments via ETF'**
  String get chhotaStocksInfo3;

  /// No description provided for @chhotaStocksInfo4.
  ///
  /// In en, this message translates to:
  /// **'Chhota Stocks will be added soon!'**
  String get chhotaStocksInfo4;

  /// No description provided for @stocksAndSegment.
  ///
  /// In en, this message translates to:
  /// **'Stocks & Segment'**
  String get stocksAndSegment;

  /// No description provided for @weightage.
  ///
  /// In en, this message translates to:
  /// **'Weightage'**
  String get weightage;

  /// No description provided for @latestNew.
  ///
  /// In en, this message translates to:
  /// **'Latest News'**
  String get latestNew;

  /// No description provided for @news.
  ///
  /// In en, this message translates to:
  /// **'News'**
  String get news;

  /// No description provided for @allBatches.
  ///
  /// In en, this message translates to:
  /// **'All Batches'**
  String get allBatches;

  /// No description provided for @track.
  ///
  /// In en, this message translates to:
  /// **'Track'**
  String get track;

  /// No description provided for @batch.
  ///
  /// In en, this message translates to:
  /// **'Batch'**
  String get batch;

  /// No description provided for @status.
  ///
  /// In en, this message translates to:
  /// **'Status'**
  String get status;

  /// No description provided for @stock.
  ///
  /// In en, this message translates to:
  /// **'Stock'**
  String get stock;

  /// No description provided for @avgPrice.
  ///
  /// In en, this message translates to:
  /// **'Avg Price'**
  String get avgPrice;

  /// No description provided for @qtyFilled.
  ///
  /// In en, this message translates to:
  /// **'Qty Filled'**
  String get qtyFilled;

  /// No description provided for @seeAll.
  ///
  /// In en, this message translates to:
  /// **'See All'**
  String get seeAll;

  /// No description provided for @lastPlacedOn.
  ///
  /// In en, this message translates to:
  /// **'Last placed on'**
  String get lastPlacedOn;

  /// No description provided for @noOrders.
  ///
  /// In en, this message translates to:
  /// **'No Orders Yet!'**
  String get noOrders;

  /// No description provided for @currentVal.
  ///
  /// In en, this message translates to:
  /// **'Current Value'**
  String get currentVal;

  /// No description provided for @totalReturns.
  ///
  /// In en, this message translates to:
  /// **'Total Returns'**
  String get totalReturns;

  /// No description provided for @currentInv.
  ///
  /// In en, this message translates to:
  /// **'Current Investment'**
  String get currentInv;

  /// No description provided for @currentReturns.
  ///
  /// In en, this message translates to:
  /// **'Current Returns'**
  String get currentReturns;

  /// No description provided for @indexVal.
  ///
  /// In en, this message translates to:
  /// **'Index Value'**
  String get indexVal;

  /// No description provided for @details.
  ///
  /// In en, this message translates to:
  /// **'Details'**
  String get details;

  /// No description provided for @investedOn.
  ///
  /// In en, this message translates to:
  /// **'Invested on'**
  String get investedOn;

  /// No description provided for @performance.
  ///
  /// In en, this message translates to:
  /// **'Performance'**
  String get performance;

  /// No description provided for @realizedAndDiv.
  ///
  /// In en, this message translates to:
  /// **'Realized Returns + Dividends'**
  String get realizedAndDiv;

  /// No description provided for @stocksAndETF.
  ///
  /// In en, this message translates to:
  /// **'Stocks/ETFs'**
  String get stocksAndETF;

  /// No description provided for @returns.
  ///
  /// In en, this message translates to:
  /// **'Returns'**
  String get returns;

  /// No description provided for @shares.
  ///
  /// In en, this message translates to:
  /// **'Shares:'**
  String get shares;

  /// No description provided for @noInvestmentYet.
  ///
  /// In en, this message translates to:
  /// **'No Investment Yet!!'**
  String get noInvestmentYet;

  /// No description provided for @openAcc.
  ///
  /// In en, this message translates to:
  /// **'Open Account'**
  String get openAcc;
}

class _TranslationsDelegate extends LocalizationsDelegate<Translations> {
  const _TranslationsDelegate();

  @override
  Future<Translations> load(Locale locale) {
    return SynchronousFuture<Translations>(lookupTranslations(locale));
  }

  @override
  bool isSupported(Locale locale) => <String>[
        'bn',
        'en',
        'gu',
        'hi',
        'kn',
        'ml',
        'mr',
        'or',
        'pa',
        'ta',
        'te',
        'ur'
      ].contains(locale.languageCode);

  @override
  bool shouldReload(_TranslationsDelegate old) => false;
}

Translations lookupTranslations(Locale locale) {
  // Lookup logic when only language code is specified.
  switch (locale.languageCode) {
    case 'bn':
      return TranslationsBn();
    case 'en':
      return TranslationsEn();
    case 'gu':
      return TranslationsGu();
    case 'hi':
      return TranslationsHi();
    case 'kn':
      return TranslationsKn();
    case 'ml':
      return TranslationsMl();
    case 'mr':
      return TranslationsMr();
    case 'or':
      return TranslationsOr();
    case 'pa':
      return TranslationsPa();
    case 'ta':
      return TranslationsTa();
    case 'te':
      return TranslationsTe();
    case 'ur':
      return TranslationsUr();
  }

  throw FlutterError(
      'Translations.delegate failed to load unsupported locale "$locale". This is likely '
      'an issue with the localizations generation tool. Please file an issue '
      'on GitHub with a reproducible sample app and the gen-l10n configuration '
      'that was used.');
}
