import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/core.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/src/error_image_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/funds/bloc/funds_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/funds/ui/funds_card.dart';
import 'package:chhota_stocks_flutter/src/feature/orderStatement/ui/order_statement_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/ui/investment/investment_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';
import 'package:scgateway_flutter_plugin/scgateway_flutter_plugin.dart';

class AccountHomeWidget extends StatefulWidget {
  final String? getFundsTxnId;
  const AccountHomeWidget({Key? key, this.getFundsTxnId}) : super(key: key);

  @override
  State<AccountHomeWidget> createState() => _AccountHomeWidgetState();
}

class _AccountHomeWidgetState extends State<AccountHomeWidget> {
  @override
  void initState() {
    super.initState();

    if (widget.getFundsTxnId != null && widget.getFundsTxnId!.isNotEmpty) {
      BlocProvider.of<FundsCubit>(context)
          .getFundDetails(widget.getFundsTxnId!);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Theme(
        data: ChhotaStocksTheme.lightThemeData,
        child: Scaffold(
          appBar: AppBar(
            systemOverlayStyle:const SystemUiOverlayStyle(
              statusBarColor: Color(0xFF6027d0),
              statusBarIconBrightness: Brightness.light,
              statusBarBrightness: Brightness.light,
            ),
            iconTheme:const  IconThemeData(
              color: Colors.white, //change your color here
            ),
            backgroundColor: const Color(0xFF6027d0),
            title:Text(
                Translations.of(context).account,
                //"Account",
                style: TextStyle(
                  color: Colors.white,
                )),
          ),
          body: ListView(children: [
            const FundsCard(),
            const SizedBox(
              height: 12,
            ),
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 18.0, vertical: 9.0),
              child: Column(
                children: [
                  InkWell(
                    onTap: () => Navigator.push(
                        context,
                        MaterialPageRoute(
                            builder: (context) => const OrderStatmentWidget())),
                    child:  ListTile(
                      title: Text(
                        Translations.of(context).orders,
                        // "Orders",
                        style:const  TextStyle(
                          fontWeight: FontWeight.w400,
                          fontSize: 16.0,
                        ),
                      ),
                      subtitle: Text(
                        Translations.of(context).ordersHistory,
                        //"Order history, status and more",
                        style: const TextStyle(
                          fontWeight: FontWeight.normal,
                          fontSize: 11.0,
                        ),
                      ),
                      trailing: const Icon(
                        Icons.arrow_forward_ios_rounded,
                        size: 20,
                      ),
                    ),
                  ),
                  const Divider(
                    height: 4.0,
                  ),
                  InkWell(
                    onTap: () => ScgatewayFlutterPlugin.logoutUser(),
                    child: ListTile(
                      title: Text(
                        Translations.of(context).logoutBroker,
                        //"Logout From Broker",
                        style:const  TextStyle(
                          fontWeight: FontWeight.w400,
                          fontSize: 16.0,
                        ),
                      ),
                      subtitle: Text(
                        Translations.of(context).disconnectYourAccount,
                       // "Disconnect your trading account",
                        style: const TextStyle(
                          fontWeight: FontWeight.w300,
                          fontSize: 11.0,
                        ),
                      ),
                      trailing:const  Icon(
                        Icons.logout,
                        size: 20,
                      ),
                    ),
                  ),
                  const Divider(
                    height: 4.0,
                  ),
                ],
              ),
            ),
            SizedBox(
              height: MediaQuery.of(context).size.height * 0.25,
            ),
            Opacity(
              opacity: 0.35,
              child: Container(
                padding: const EdgeInsets.symmetric(vertical: 25.0),
                child: Column(
                  children: [
                   Text(
                    Translations.of(context).poweredBy,
                      //"Powered by",
                      style: TextStyle(fontSize: 11.0),
                    ),
                   const  SizedBox(
                      height: 7,
                    ),
                     SvgPicture.network(
                      "https://assets.chhotastock.com/app/chhota-stock-textbelow-light.svg",
                      width: 75,
                    ),
                   const  SizedBox(
                      height: 5,
                    ),
                   Text(
                     Translations.of(context).version,
                      //"Version 1.0",
                      style: const TextStyle(fontSize: 9.0),
                    ),
                  ],
                ),
              ),
            )
          ]),
        ));
  }
}
