import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/bloc/discover_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/model/discover_model.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/ui/smallcase_card_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:shimmer/shimmer.dart';

class DiscoverWidget extends StatelessWidget {
  const DiscoverWidget({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<DiscoverCubit, DiscoverState>(builder: (context, state) {
      if (state is DiscoverSuccess &&
          state.discoverResult.smallCaseData?.listOfSmallcases != null) {
        return       Wrap(
         // mainAxisSize: MainAxisSize.min,
          children: [
            _DiscoverWidget(
                listOfSmallcases:
                state.discoverResult.smallCaseData!.listOfSmallcases!),
          ],
        );
      } else if (state is DiscoverFailed) {
        return const ChhotaStocksErrorWidget();
      }

      return Wrap(
        children: const [
           Padding(
            padding:  EdgeInsets.symmetric(horizontal: 20.0, vertical: 20),
            child:  ShimmerLoader(),
          ),
        ],
      );
    });
  }
}

class _DiscoverWidget extends StatefulWidget {
  final List<SmallCases> listOfSmallcases;

  const _DiscoverWidget({Key? key, required this.listOfSmallcases})
      : super(key: key);

  @override
  State<_DiscoverWidget> createState() => _DiscoverWidgetState();
}

class _DiscoverWidgetState extends State<_DiscoverWidget> {
  @override
  Widget build(BuildContext context) {
    if (widget.listOfSmallcases.isEmpty) {
      return Container(
          height: 50,
          alignment: Alignment.center,
          child: Text(
              Translations.of(context).emptyBasket,
            overflow: TextOverflow.ellipsis,
          // "No Chhota Stocks available!"

          ));
    }

    return Container(
      height: 300,
      child: ListView.builder(
          itemCount: widget.listOfSmallcases.length,
          scrollDirection: Axis.horizontal,
          shrinkWrap: true,

          padding:
          const EdgeInsets.only(top: 10, bottom: 10.0, left: 10, right: 10),
          itemBuilder: (context, index) {
            return Padding(
              padding: const EdgeInsets.all(8.0),
              child: SmallcaseCardWidget(
                  smallCases: widget.listOfSmallcases[index]),
            );
          }),
    );
  }
}
