import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/core/functions/functions.dart';
import 'package:chhota_stocks_flutter/src/feature/commonWidget/common_widgets.dart';
import 'package:chhota_stocks_flutter/src/feature/funds/bloc/funds_cubit.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_svg/svg.dart';

class FundsCard extends StatelessWidget {
  const FundsCard({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<FundsCubit, FundsState>(builder: (context, state) {
      if (state is FundsSuccess) {
        return Container(
            height: 135,
            color: const Color(0xFF6027d0),
            padding: const EdgeInsets.only(
                left: 32.0, right: 32.0, bottom: 22.0, top: 22.0),
            child: Stack(children: [
              Row(
                children: [
                  _ColumnCard(
                    title: Translations.of(context).funds,
                    isFunds: true,

                    subTitle:
                        "₹ ${indiaFormat.format(state.transactionCallbackOnSuccess.data?.funds).replaceAll("INR", "")}",
                    description:
                        state.transactionCallbackOnSuccess.broker ?? "--",
                  ),
                ],
              ),
              Positioned(
                  right: 1,
                  bottom: 1,
                  child: SvgPicture.network(
                    "https://img.smartspends.com/static/images/etmoneyweb/insurance/empower-family.svg",
                  ))
            ]));
      } else if (state is FundsLoading) {
        return const ShimmerLoader(
          height: 135,
          borderRadius: 0.0,
          color:  Color(0xFF6027d0),
        );
      }

      return Container(
          color:const  Color(0xFF6027d0),
          height: 135,
          padding: const EdgeInsets.only(
              left: 32.0, right: 32.0, bottom: 22.0, top: 22.0),
          child: Stack(children: [
            Row(
              children: [
                _ColumnCard(
                  title: Translations.of(context).funds,
                  isFunds: true,

                  //"Funds",
                  subTitle: "₹ --",
                  description: Translations.of(context).noBrokerConnected
                  //"No broker connected",
                ),
                // SizedBox(
                //   width: 60,
                // ),
                // _ColumnCard(
                //   title: "Broker",
                //   subTitle: "--",
                // ),
                // SizedBox(
                //   width: 22.0,
                // ),
              ],
            ),
            Positioned(
                right: 1,
                bottom: 1,
                child: SvgPicture.network(
                  "https://img.smartspends.com/static/images/etmoneyweb/insurance/empower-family.svg",
                ))
          ]));
    });
  }
}

class RefreshBtn extends StatelessWidget {
  const RefreshBtn({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return InkWell(
        onTap: () => BlocProvider.of<FundsCubit>(context).portfolioFunds(),
        child: const Icon(
          Icons.refresh,
          color: Colors.white,
          size: 24,
        ));
  }
}

class _ColumnCard extends StatelessWidget {
  final String title;
  final String subTitle;
  final String description;
  final  bool isFunds;
  const _ColumnCard({
    Key? key,
    required this.title,
    required this.subTitle,
    required this.description,
    this.isFunds=false,
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Row(mainAxisAlignment: MainAxisAlignment.start, children: [
          Text(
            title,
            style: const TextStyle(
              fontSize: 13.0,
              fontWeight: FontWeight.w400,
              color: Colors.white,
            ),
            overflow: TextOverflow.ellipsis,
          ),
          SizedBox(
            width: 5.0,
          ),
          isFunds
              ? const RefreshBtn()
              :const  SizedBox(
                  width: 0,
                ),
        ]),
        const SizedBox(
          height: 5.0,
        ),
        Text(
          subTitle,
          style: const TextStyle(
            fontSize: 21.0,
            fontWeight: FontWeight.w600,
            color: Colors.white,
          ),
          overflow: TextOverflow.ellipsis,
        ),
        const SizedBox(
          height: 5.0,
        ),
        Text(
          description,
          style: const TextStyle(
            fontSize: 11.0,
            fontWeight: FontWeight.normal,
            color: Colors.white,
          ),
          overflow: TextOverflow.ellipsis,
        ),
      ],
    );
  }
}
