import 'package:chhota_stocks_flutter/l10n/translations.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/bloc/discover_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/discover/ui/discover_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/bloc/init_sdk_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/initSDK/ui/profile_icon_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/bloc/aggregated_bloc/aggregated_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/bloc/portfolio_summary/portfolio_summary_cubit.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/ui/aggregateUi/portfolio_card.dart';
import 'package:chhota_stocks_flutter/src/feature/portfolio/ui/investment/investment_widget.dart';
import 'package:chhota_stocks_flutter/src/feature/saveLead/ui/lead_gen_btn.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'home_header_card_desc.dart';
import 'init_chhotastocks_widget.dart';

class HomeWidget extends StatefulWidget {
  final VoidCallback? onDone;
  const HomeWidget({Key? key, this.onDone}) : super(key: key);

  @override
  State<HomeWidget> createState() => _HomeWidgetState();
}

class DecoratedTabBar extends StatelessWidget implements PreferredSizeWidget {
  final TabBar tabBar;
  final BoxDecoration decoration;

  const DecoratedTabBar({required this.tabBar, required this.decoration});

  @override
  Size get preferredSize => tabBar.preferredSize;

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Positioned.fill(child: Container(decoration: decoration)),
        tabBar,
      ],
    );
  }
}

class _HomeWidgetState extends State<HomeWidget> with TickerProviderStateMixin {
  late TabController _tabController;

  @override
  void initState() {
    super.initState();
    context.read<DiscoverCubit>().discover();
    context.read<AggregatedCubit>().getPortfolioAggregate();
    context.read<PortfolioSummaryCubit>().portfolioSummary();
    _tabController = TabController(length: 2, vsync: this, initialIndex: 0);
  }

  @override
  void dispose() {
    super.dispose();
    _tabController.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: RefreshIndicator(
        onRefresh: () async {
          context.read<DiscoverCubit>().discover();
          context.read<AggregatedCubit>().getPortfolioAggregate();
          context.read<PortfolioSummaryCubit>().portfolioSummary();
        },
        child: NestedScrollView(
          headerSliverBuilder: (context, innerBoxIsScrolled) {
            return [
              SliverAppBar(
                systemOverlayStyle:const  SystemUiOverlayStyle(
                  statusBarColor: Colors.white,
                  statusBarIconBrightness: Brightness.dark,
                  statusBarBrightness: Brightness.light,
                ),
                elevation: 0,
                title: const _Header(),
                leading: IconButton(onPressed: ()=>chhotaStocksNavigatorKey.currentState!.pop(), icon: const Icon(Icons.arrow_back,size: 30,color: Colors.black,)),
                actions: const [
                  ProfileIconWidget(),
                ],
              ),
              const SliverToBoxAdapter(
                child: SizedBox(
                  height: 16.0,
                ),
              ),
              const SliverToBoxAdapter(
                child: HomeHeaderCardDesc(),
              ),
              const SliverToBoxAdapter(
                child: SizedBox(
                  height: 8.0,
                ),
              ),
              // const SliverToBoxAdapter(
              //   child: LeadGenButton(),
              // ),
              const SliverToBoxAdapter(
                child: SizedBox(
                  height: 8.0,
                ),
              ),
              const SliverToBoxAdapter(
                child: PortfolioCard(
                  isOverview: true,
                ),
              ),
              SliverToBoxAdapter(
                child: PreferredSize(
                  preferredSize: Size.fromHeight(50.0),
                  child: Align(
                    alignment: Alignment.centerLeft,
                    child: DecoratedTabBar(
                      decoration: BoxDecoration(
                        border: Border(
                          bottom: BorderSide(
                            color: Colors.grey.withOpacity(0.2),
                            width: 1.0,
                          ),
                        ),
                      ),
                      tabBar: TabBar(
                        indicator: const UnderlineTabIndicator(
                          borderSide: BorderSide(
                            width: 1,
                            color: Color(0xFF646464),
                          ),
                        ),
                        isScrollable: true,
                        controller: _tabController,
                        unselectedLabelColor: Colors.black,
                        padding: EdgeInsets.symmetric(horizontal: 18.0),
                        indicatorPadding:
                            const EdgeInsets.symmetric(horizontal: 12.0),
                        indicatorWeight: 1,
                        labelColor: const Color(0xFF207ae0),
                        tabs: <Widget>[
                          Tab(
                            icon: Text(
                              Translations.of(context).discover,
                              style: Theme.of(context)
                                  .appBarTheme
                                  .titleTextStyle
                                  ?.copyWith(fontSize: 14.0),
                            ),
                          ),
                          Tab(
                            icon: Text(Translations.of(context).investment,
                                style: Theme.of(context)
                                    .appBarTheme
                                    .titleTextStyle
                                    ?.copyWith(fontSize: 14.0)),
                          ),
                        ],
                      ),
                    ),
                  ),
                ),
              ),
            ];
          },
          body: TabBarView(
              controller: _tabController,
              children: const [DiscoverWidget(), InvestmentWidget()]),
        ),
      ),
    );
  }
}

class _Header extends StatelessWidget {
  const _Header({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<InitSdkCubit, InitSdkState>(builder: (context, state) {
      // if(state is InitSdkSuccess){
      //   return Text( "Hello ${state.name}!",style: Theme.of(context).appBarTheme.titleTextStyle,);
      // }

      // return Text( "Hello !",style: Theme.of(context).appBarTheme.titleTextStyle,);
      return Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
        SizedBox(
          height: 10,
        ),
        Text(
          Translations.of(context).portFolio,
          style: TextStyle(
            color: Colors.black,
          ),
        ),
        SizedBox(
          height: 5,
        ),
        Text(
          Translations.of(context).portfolioDesc,
          style: TextStyle(
            color: Colors.grey,
            fontSize: 14,
            fontWeight: FontWeight.w400,
          ),
        ),
      ]);
    });
  }
}
